==> postcss-4.1.1.tgz: package/lib/list.js <==
"use strict";

module.exports = {

    split: (function (_split) {
        var _splitWrapper = function split(_x, _x2, _x3) {
            return _split.apply(this, arguments);
        };

        _splitWrapper.toString = function () {
            return _split.toString();
        };

        return _splitWrapper;
    })(function (string, separators, last) {
        var array = [];
        var current = "";
        var split = false;

        var func = 0;
        var quote = false;
        var escape = false;

        for (var i = 0; i < string.length; i++) {
            var letter = string[i];

            if (quote) {
                if (escape) {
                    escape = false;
                } else if (letter === "\\") {
                    escape = true;
                } else if (letter === quote) {
                    quote = false;
                }
            } else if (letter === "\"" || letter === "'") {
                quote = letter;
            } else if (letter === "(") {
                func += 1;
            } else if (letter === ")") {
                if (func > 0) func -= 1;
            } else if (func === 0) {
                for (var j = 0; j < separators.length; j++) {
                    if (letter === separators[j]) split = true;
                }
            }

            if (split) {
                if (current !== "") array.push(current.trim());
                current = "";
                split = false;
            } else {
                current += letter;
            }
        }

        if (last || current !== "") array.push(current.trim());
        return array;
    }),

    space: function space(string) {
        var spaces = [" ", "\n", "\t"];
        return this.split(string, spaces);
    },

    comma: (function (_comma) {
        var _commaWrapper = function comma(_x) {
            return _comma.apply(this, arguments);
        };

        _commaWrapper.toString = function () {
            return _comma.toString();
        };

        return _commaWrapper;
    })(function (string) {
        var comma = ",";
        return this.split(string, [comma], true);
    })

};

==> postcss-4.1.2.tgz: package/lib/list.js <==
"use strict";

var list = {

    split: (function (_split) {
        var _splitWrapper = function split(_x, _x2, _x3) {
            return _split.apply(this, arguments);
        };

        _splitWrapper.toString = function () {
            return _split.toString();
        };

        return _splitWrapper;
    })(function (string, separators, last) {
        var array = [];
        var current = "";
        var split = false;

        var func = 0;
        var quote = false;
        var escape = false;

        for (var i = 0; i < string.length; i++) {
            var letter = string[i];

            if (quote) {
                if (escape) {
                    escape = false;
                } else if (letter === "\\") {
                    escape = true;
                } else if (letter === quote) {
                    quote = false;
                }
            } else if (letter === "\"" || letter === "'") {
                quote = letter;
            } else if (letter === "(") {
                func += 1;
            } else if (letter === ")") {
                if (func > 0) func -= 1;
            } else if (func === 0) {
                for (var j = 0; j < separators.length; j++) {
                    if (letter === separators[j]) split = true;
                }
            }

            if (split) {
                if (current !== "") array.push(current.trim());
                current = "";
                split = false;
            } else {
                current += letter;
            }
        }

        if (last || current !== "") array.push(current.trim());
        return array;
    }),

    space: function space(string) {
        var spaces = [" ", "\n", "\t"];
        return list.split(string, spaces);
    },

    comma: (function (_comma) {
        var _commaWrapper = function comma(_x) {
            return _comma.apply(this, arguments);
        };

        _commaWrapper.toString = function () {
            return _comma.toString();
        };

        return _commaWrapper;
    })(function (string) {
        var comma = ",";
        return list.split(string, [comma], true);
    })

};

module.exports = list;
